@@ -1,15 +1,13 @@
-## zzz.R (2003-05-05)
+## zzz.R (2008-01-14)
 
 ##   Library Loading
 
-## Copyright 2003 Emmanuel Paradis
+## Copyright 2003-2008 Emmanuel Paradis
 
 ## This file is part of the R-package `ape'.
 ## See the file ../COPYING for licensing issues.
 
 .First.lib <- function(lib, pkg) {
-    require(gee)
-    require(nlme)
-    require(lattice)
+    require(nlme, quietly = TRUE)
     library.dynam("ape", pkg, lib)
 }
